[glib] codegen: Fix a typo in g_variant_get_objv()



commit 567e5548bbe8bd1711a7ca2cc92268a9b0a76494
Author: Philip Withnall <withnall endlessm com>
Date:   Wed Jan 17 16:12:25 2018 +0000

    codegen: Fix a typo in g_variant_get_objv()
    
    g_variant_get_objpathv() doesn’t exist. The code actually meant
    g_variant_get_objv().
    
    This fixes a leak with `ao`-type properties in generated code.
    Previously they wouldn’t be freed; now the container is (correctly)
    freed.
    
    Signed-off-by: Philip Withnall <withnall endlessm com>
    
    https://bugzilla.gnome.org/show_bug.cgi?id=770335

 gio/gdbus-2.0/codegen/codegen.py |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/gio/gdbus-2.0/codegen/codegen.py b/gio/gdbus-2.0/codegen/codegen.py
index 6de78d2..d98f897 100644
--- a/gio/gdbus-2.0/codegen/codegen.py
+++ b/gio/gdbus-2.0/codegen/codegen.py
@@ -1830,9 +1830,9 @@ class CodeGenerator:
             # for details
             #
             free_container = False;
-            if p.arg.gvariant_get == 'g_variant_get_strv' or p.arg.gvariant_get == 'g_variant_get_objpathv' 
or p.arg.gvariant_get == 'g_variant_get_bytestring_array':
+            if p.arg.gvariant_get == 'g_variant_get_strv' or p.arg.gvariant_get == 'g_variant_get_objv' or 
p.arg.gvariant_get == 'g_variant_get_bytestring_array':
                 free_container = True;
             # If already using an old value for strv, objpathv, bytestring_array (see below),
             # then just return that... that way the result from multiple consecutive calls
             # to the getter are valid as long as they're freed
             #
@@ -1830,9 +1830,9 @@ class CodeGenerator:
p.arg.gvariant_get == 'g_variant_get_bytestring_array':
                 free_container = True;
-            # If already using an old value for strv, objpathv, bytestring_array (see below),
+            # If already using an old value for strv, objv, bytestring_array (see below),
             # then just return that... that way the result from multiple consecutive calls
             # to the getter are valid as long as they're freed


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]